import logging
logging.basicConfig()

from .LogService import log_service, LogService
from .CameraLogService import CameraLogService, CameraLogServiceManager